@@ -35,7 +35,11 @@
 #include "charset.h"
 
 #ifndef PACKAGE_DATA_DIR
-#    include "../pixmaps/EasyTAG_logo.xpm"
+#   include "../pixmaps/EasyTAG_logo.xpm"
+#endif
+
+#ifdef WIN32
+#   include "win32dep.h"
 #endif
 
 
@@ -101,16 +105,18 @@ void Show_About_Window (void)
     GtkWidget *Logo;
     GdkPixmap *pixmap;
     GdkBitmap *mask;
-    gchar temp[MAX_STRING_LEN];
-    FILE *file;
-    gint i;
+    gchar  temp[MAX_STRING_LEN];
     gchar *temp_str;
+    gint i;
+#ifdef PACKAGE_DATA_DIR
+    FILE *file;
     gchar *tmp = NULL;
+#endif
     gchar *description_text = 
             _(""
             "    EasyTAG is an utility for viewing and editing tags for MP3, MP2, "
-            "FLAC, Ogg Vorbis, MusePack and Monkey's Audio files. Its simple and "
-            "nice GTK+ interface makes tagging easier under GNU/Linux."
+            "FLAC, Ogg Vorbis, MP4/AAC, MusePack and Monkey's Audio files. Its "
+            "simple and nice GTK+ interface makes tagging easier under GNU/Linux."
             "");
 
 
@@ -143,6 +149,7 @@ void Show_About_Window (void)
             {"    - Morten Brix Pedersen ",         _("(Danish translation)")},
             {"    - Apollon Oikonomopoulos ",       _("(Greek translation)")},
             {"    - doutor zero ",                  _("(Brazilian Portuguese translation)")},
+            {"    - Luchezar P. Petkov ",           _("(Bulgarian translation)")},
             {NULL,NULL}
             };
 
@@ -150,6 +157,7 @@ void Show_About_Window (void)
     gchar *general_thanks_text = 
             "    - Daniel Drake (GTK2 port)\n"
             "    - Mihael Vrbanec (GTK2 port)\n"
+            "    - Michael Pujos (Win32 port)\n"
             "    - Andrew Shuvalov\n"
             "    - Sergey Zhumatiy\n"
             "    - Kevin Venkiteswaran\n"
@@ -180,6 +188,10 @@ void Show_About_Window (void)
             "    - Justus Schwartz\n"
             "    - Fredrik Noring\n"
             "    - Guilherme Destefani\n"
+            "    - Michael Ihde\n"
+            "    - Stewart Whitman\n"
+            "    - Javier Kohen\n"
+            "    - Alexey Illarionov\n"
             "";
 
 
@@ -262,6 +274,11 @@ void Show_About_Window (void)
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 #endif
 
+#ifndef ENABLE_MP4
+    Label = gtk_label_new(_("(MP4/AAC file support disabled)"));
+    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
+#endif
+
     /* Insert a blank line */
     Label = gtk_label_new("");
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
@@ -332,7 +349,7 @@ void Show_About_Window (void)
     {
         // Translator name
         if (!g_utf8_validate(translations_thanks_text[i][0], -1, NULL))
-            temp_str = convert_string(translations_thanks_text[i][0], "iso-8859-1", "utf-8");
+            temp_str = convert_string(translations_thanks_text[i][0], "iso-8859-1", "utf-8",TRUE);
         else
             temp_str = g_strdup(translations_thanks_text[i][0]);
         gtk_text_buffer_insert(TextBuffer, &iter, temp_str, -1);
@@ -340,7 +357,7 @@ void Show_About_Window (void)
 
         // Translation language
         if (!g_utf8_validate(translations_thanks_text[i][1], -1, NULL))
-            temp_str = convert_string(translations_thanks_text[i][1], "iso-8859-1", "utf-8");
+            temp_str = convert_string(translations_thanks_text[i][1], "iso-8859-1", "utf-8",TRUE);
         else
             temp_str = g_strdup(translations_thanks_text[i][1]);
         gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, temp_str, -1,
@@ -407,7 +424,7 @@ void Show_About_Window (void)
                 temp[strlen(temp)-1]='\0';
 
             if (!g_utf8_validate(temp, -1, NULL))
-                tmp = convert_string(temp, "iso-8859-1", "utf-8");
+                tmp = convert_string(temp, "iso-8859-1", "utf-8",TRUE);
             else
                 tmp = g_strdup(temp);
 
@@ -465,5 +482,9 @@ void Show_About_Window (void)
 
 void About_Window_Go_To_Home_Page (void)
 {
+#ifdef WIN32
+    ET_win32_notify_uri(WEBPAGE);
+#else
     system("gnome-moz-remote "WEBPAGE);
+#endif
 }
