@@ -185,55 +185,58 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
         { AM_SORT_ASCENDING_FILE_SAMPLERATE,  GTK_STOCK_SORT_ASCENDING,  _("Ascending by samplerate"),       NULL, _("Ascending by samplerate"),       G_CALLBACK(Menu_Sort_Action) },
         { AM_SORT_DESCENDING_FILE_SAMPLERATE, GTK_STOCK_SORT_DESCENDING, _("Descending by samplerate"),      NULL, _("Descending by samplerate"),      G_CALLBACK(Menu_Sort_Action) },
 
+#ifndef WIN32
         { AM_BROWSE_FILE_WITH,   GTK_STOCK_OPEN,             _("Open File(s) with ..."),      NULL,                _("Open File(s) with ..."),     G_CALLBACK(Browser_Open_Run_Program_List_Window) },
+#endif
         { AM_SELECT_ALL_FILES,   "easytag-select-all",       _("Select All Files"),           "<Control>A",        _("Select All Files"),          G_CALLBACK(Action_Select_All_Files) },
         { AM_UNSELECT_ALL_FILES, "easytag-unselect-all",     _("Unselect All Files"),         "<Shift><Control>A", _("Unselect All Files"),        G_CALLBACK(Action_Unselect_All_Files) },
         { AM_INVERT_SELECTION,   "easytag-invert-selection", _("Invert Files Selection"),     "<Control>I",        _("Invert Files Selection"),    G_CALLBACK(Action_Invert_Files_Selection) },
         { AM_DELETE_FILE,        GTK_STOCK_DELETE,           _("Delete File(s)"),             NULL,                _("Delete File(s)"),            G_CALLBACK(Action_Delete_Selected_Files) },
-        { AM_FIRST,              GTK_STOCK_GOTO_FIRST,       _("_First File"),                "<Control>F",        _("First File"),                G_CALLBACK(Action_Select_First_File) },
-        { AM_PREV,               GTK_STOCK_GO_BACK,          _("_Previous File"),             "<Control>P",        _("Previous File"),             G_CALLBACK(Action_Select_Prev_File) },
-        { AM_NEXT,               GTK_STOCK_GO_FORWARD,       _("_Next File"),                 "<Control>N",        _("Next File"),                 G_CALLBACK(Action_Select_Next_File) },
-        { AM_LAST,               GTK_STOCK_GOTO_LAST,        _("_Last File"),                 "<Control>L",        _("Last File"),                 G_CALLBACK(Action_Select_Last_File) },
+        { AM_FIRST,              GTK_STOCK_GOTO_FIRST,       _("_First File"),                "<Control>Home",     _("First File"),                G_CALLBACK(Action_Select_First_File) },
+        { AM_PREV,               GTK_STOCK_GO_BACK,          _("_Previous File"),             "Page_Up",           _("Previous File"),             G_CALLBACK(Action_Select_Prev_File) },
+        { AM_NEXT,               GTK_STOCK_GO_FORWARD,       _("_Next File"),                 "Page_Down",         _("Next File"),                 G_CALLBACK(Action_Select_Next_File) },
+        { AM_LAST,               GTK_STOCK_GOTO_LAST,        _("_Last File"),                 "<Control>End",      _("Last File"),                 G_CALLBACK(Action_Select_Last_File) },
         // XXX GTK1 version uses Ctrl+C for scanner, this doesnt work in GTK1 as its copy! in gtk2, behaviour is different
         // and binding Ctrl+C effectively stops the user copying text..
         { AM_SCAN,               "easytag-scan",             _("S_can File(s)"),              NULL,                _("Scan File(s)"),              G_CALLBACK(Action_Scan_Selected_Files) },
         { AM_REMOVE,             GTK_STOCK_CLEAR,            _("_Remove Tag(s)"),             "<Control>R",        _("Remove Tag(s)"),             G_CALLBACK(Action_Remove_Selected_Tags) },
-        { AM_UNDO,               GTK_STOCK_UNDO,             _("_Undo Last File(s) Changes"), "<Control>U",        _("Undo Last File(s) Changes"), G_CALLBACK(Action_Undo_Selected_Files) },
-        { AM_REDO,               GTK_STOCK_REDO,             _("R_edo Last File(s) Changes"), "<Control>E",        _("Redo Last File(s) Changes"), G_CALLBACK(Action_Redo_Selected_File) },
+        { AM_UNDO,               GTK_STOCK_UNDO,             _("_Undo Last File(s) Changes"), "<Control>Z",        _("Undo Last File(s) Changes"), G_CALLBACK(Action_Undo_Selected_Files) },
+        { AM_REDO,               GTK_STOCK_REDO,             _("R_edo Last File(s) Changes"), "<Shift><Control>Z", _("Redo Last File(s) Changes"), G_CALLBACK(Action_Redo_Selected_File) },
         { AM_SAVE,               GTK_STOCK_SAVE,             _("_Save File(s)"),              "<Control>S",        _("Save File(s)"),              G_CALLBACK(Action_Save_Selected_Files) },
-        { AM_UNDO_HISTORY,       GTK_STOCK_UNDO,             _("Undo Last Changes"),          "<Alt><Control>U",   _("Undo Last Changes"),         G_CALLBACK(Action_Undo_From_History_List) },
-        { AM_REDO_HISTORY,       GTK_STOCK_REDO,             _("Redo Last Changes"),          "<Alt><Control>R",   _("Redo Last Changes"),         G_CALLBACK(Action_Redo_From_History_List) },
+        { AM_UNDO_HISTORY,       GTK_STOCK_UNDO,             _("Undo Last Changes"),          NULL,                _("Undo Last Changes"),         G_CALLBACK(Action_Undo_From_History_List) },
+        { AM_REDO_HISTORY,       GTK_STOCK_REDO,             _("Redo Last Changes"),          NULL,                _("Redo Last Changes"),         G_CALLBACK(Action_Redo_From_History_List) },
         { AM_QUIT,               GTK_STOCK_QUIT,             _("_Quit"),                      "<Control>Q",        _("Quit"),                      G_CALLBACK(Quit_MainWindow) },
 
         { MENU_BROWSER,                NULL,                   _("_Browser") },
-        { AM_LOAD_HOME_DIR,            GTK_STOCK_HOME,         _("Go to _Home Directory"),         "<Control>H",        _("Go to Home Directory"),          G_CALLBACK(Browser_Load_Home_Directory) },
+        { AM_LOAD_HOME_DIR,            GTK_STOCK_HOME,         _("Go to _Home Directory"),         "<Alt>Home",         _("Go to Home Directory"),          G_CALLBACK(Browser_Load_Home_Directory) },
         { AM_LOAD_DEFAULT_DIR,         GTK_STOCK_HARDDISK,     _("Go to _Default Directory"),      "<Control>D",        _("Go to Default Directory"),       G_CALLBACK(Browser_Load_Default_Directory) },
         { AM_SET_PATH_AS_DEFAULT,      GTK_STOCK_JUMP_TO,      _("Set _Current Path as Default"),  NULL,                _("Set Current Path as Default"),   G_CALLBACK(Set_Current_Path_As_Default) },
         { AM_TREE_OR_ARTISTALBUM_VIEW, "easytag-artist-album", _("Tree View | Artist-Album View"), NULL,                _("Tree View | Artist-Album View"), G_CALLBACK(Menu_Sort_Action) },
-        { AM_RENAME_DIR,               GTK_STOCK_INDEX,        _("Rename Directory ..."),          "<Control><Shift>D", _("Rename Directory ..."),          G_CALLBACK(Browser_Open_Rename_Directory_Window) },
+        { AM_RENAME_DIR,               GTK_STOCK_INDEX,        _("Rename Directory ..."),          "F2",                _("Rename Directory ..."),          G_CALLBACK(Browser_Open_Rename_Directory_Window) },
         { AM_RELOAD_DIRECTORY,         GTK_STOCK_REFRESH,      _("Reload Directory"),              "F5",                _("Reload Directory"),              G_CALLBACK(Browser_Reload_Directory) },
+#ifndef WIN32
         { AM_BROWSE_DIRECTORY_WITH,    GTK_STOCK_EXECUTE,      _("Browse Directory with ..."),     NULL,                _("Browse Directory with ..."),     G_CALLBACK(Browser_Open_Run_Program_Tree_Window) },
+#endif
         { AM_COLLAPSE_TREE,            NULL,                   _("_Collapse Tree"),                "<Control><Shift>C", _("_Collapse Tree"),                G_CALLBACK(Browser_Tree_Collapse) },
         { AM_INITIALIZE_TREE,          GTK_STOCK_REFRESH,      _("_Refresh Tree"),                 "<Control><Shift>R", _("_Refresh Tree"),                 G_CALLBACK(Browser_Tree_Rebuild) },
 
-        { MENU_SCANNER,              NULL,           _("S_canner") },
-        { AM_SCANNER_FILL_TAG,       "easytag-scan", _("_Fill Tag(s) ..."),                     NULL, _("Fill Tag(s) ..."),                 G_CALLBACK(Scan_Use_Fill_Tag_Scanner) },
-        { AM_SCANNER_RENAME_FILE,    "easytag-scan", _("_Rename File(s) and Directory ..."),    NULL, _("Rename File(s) and Directory ..."),G_CALLBACK(Scan_Use_Rename_File_Scanner) },
-        { AM_SCANNER_PROCESS_FIELDS, "easytag-scan", _("_Process Field(s) ..."),                NULL, _("Process Fields(s) ..."),           G_CALLBACK(Scan_Use_Process_Fields_Scanner) },
+        { MENU_SCANNER,              NULL,                  _("S_canner") },
+        { AM_SCANNER_FILL_TAG,       "easytag-scan",        _("_Fill Tag(s) ..."),                  NULL,         _("Fill Tag(s) ..."),                 G_CALLBACK(Scan_Use_Fill_Tag_Scanner) },
+        { AM_SCANNER_RENAME_FILE,    "easytag-scan",        _("_Rename File(s) and Directory ..."), NULL,         _("Rename File(s) and Directory ..."),G_CALLBACK(Scan_Use_Rename_File_Scanner) },
+        { AM_SCANNER_PROCESS_FIELDS, "easytag-scan",        _("_Process Field(s) ..."),             NULL,         _("Process Fields(s) ..."),           G_CALLBACK(Scan_Use_Process_Fields_Scanner) },
 
-        { MENU_MISC,            NULL,              _("_Misc") },
-        { AM_SEARCH_FILE,       GTK_STOCK_FIND,    _("S_earch File(s) ..."),         "<Alt>E", _("Search File(s)..."),           G_CALLBACK(Open_Search_File_Window) },
-        { AM_CDDB_SEARCH,       GTK_STOCK_CDROM,   _("_CD Data Base Search ..."),    NULL,     _("CDDB Search ..."),             G_CALLBACK(Open_Cddb_Window) },
-        { AM_FILENAME_FROM_TXT, GTK_STOCK_OPEN,    _("Load Filenames from TXT ..."), "<Alt>T", _("Load Filenames from TXT ..."), G_CALLBACK(Open_Load_Filename_Window) },
-        { AM_WRITE_PLAYLIST,    GTK_STOCK_SAVE_AS, _("Write Playlist ..."),          "<Alt>W", _("Write Playlist ..."),          G_CALLBACK(Open_Write_Playlist_Window) },
-        { AM_RUN_AUDIO_PLAYER,  "easytag-sound",   _("Run Audio Player"),            "<Alt>X", _("Run Audio Player"),            G_CALLBACK(Run_Audio_Player_Using_Selection) },
+        { MENU_MISC,                NULL,                   _("_Misc") },
+        { AM_SEARCH_FILE,           GTK_STOCK_FIND,         _("Search _File(s) ..."),               "<Control>F", _("Search File(s)..."),               G_CALLBACK(Open_Search_File_Window) },
+        { AM_CDDB_SEARCH,           GTK_STOCK_CDROM,        _("_CD Data Base Search ..."),          NULL,         _("CDDB Search ..."),                 G_CALLBACK(Open_Cddb_Window) },
+        { AM_FILENAME_FROM_TXT,     GTK_STOCK_OPEN,         _("Load Filenames from TXT ..."),       "<Alt>T",     _("Load Filenames from TXT ..."),     G_CALLBACK(Open_Load_Filename_Window) },
+        { AM_WRITE_PLAYLIST,        GTK_STOCK_SAVE_AS,      _("Write Playlist ..."),                "<Alt>W",     _("Write Playlist ..."),              G_CALLBACK(Open_Write_Playlist_Window) },
+        { AM_RUN_AUDIO_PLAYER,      "easytag-sound",        _("Run Audio Player"),                  "<Alt>X",     _("Run Audio Player"),                G_CALLBACK(Run_Audio_Player_Using_Selection) },
 
-        { MENU_SETTINGS,          NULL,                  _("_Settings") },
-        { AM_OPEN_OPTIONS_WINDOW, GTK_STOCK_PREFERENCES, _("_Preferences ..."),         "<Alt>P", _("Preferences ..."),         G_CALLBACK(Open_OptionsWindow) },
-        { AM_SAVE_CONFIG,         GTK_STOCK_SAVE,        _("Save _Configuration Now"),  "<Alt>C", _("Save Configuration Now"),  G_CALLBACK(Save_Config_Now) },
+        { MENU_SETTINGS,            NULL,                   _("_Settings") },
+        { AM_OPEN_OPTIONS_WINDOW,   GTK_STOCK_PREFERENCES,  _("_Preferences ..."),                  "<Alt>P",     _("Preferences ..."),                 G_CALLBACK(Open_OptionsWindow) },
 
-        { MENU_HELP,            NULL,           _("_Help") },
-        { AM_OPEN_ABOUT_WINDOW, GTK_STOCK_HELP, _("_About"), "<Alt>A", _("About"), G_CALLBACK(Show_About_Window) },
+        { MENU_HELP,                NULL,                   _("_Help") },
+        { AM_OPEN_ABOUT_WINDOW,     GTK_STOCK_HELP,         _("_About"),                            NULL,         _("About"),                           G_CALLBACK(Show_About_Window) },
 
 
         /*
@@ -254,8 +257,11 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
 
     GtkToggleActionEntry ToggleActionEntries[] = 
     {
-        { AM_RECURSE,         GTK_STOCK_INDEX,        _("Browse _Sub-directories"),                         NULL, _("Browse _Sub-directories"),                          NULL,                                    FALSE },
-        { AM_VIEWMODE_TOGGLE, "easytag-artist-album", _("Show tree browser / Display by Artist and Album"), NULL, _ ("Show tree browser / Display by Artist and Album"), G_CALLBACK(Action_Select_Browser_Style), FALSE },
+        { AM_BROWSE_SUBDIR,      GTK_STOCK_INDEX,        _("Browse _Sub-directories"),                         NULL, _("Browse _Sub-directories"),                         NULL,                                    FALSE },
+#ifndef WIN32 // No sense here for Win32, "hidden" means : starts with a '.'
+        { AM_BROWSER_HIDDEN_DIR, NULL,                   _("Show Hidden Directories"),                         NULL, _("Show Hidden Directories"),                         G_CALLBACK(Browser_Tree_Rebuild),     FALSE },
+#endif
+        { AM_VIEWMODE_TOGGLE,    "easytag-artist-album", _("Show tree browser / Display by Artist and Album"), NULL, _("Show tree browser / Display by Artist and Album"), G_CALLBACK(Action_Select_Browser_Style), FALSE },
     };
 
     GError *error = NULL;
@@ -290,17 +296,16 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
     gtk_action_group_add_toggle_actions(ActionGroup, ToggleActionEntries, num_toggle_entries, NULL);
 
     UIManager = gtk_ui_manager_new();
-    if (!gtk_ui_manager_add_ui_from_string (UIManager, ui_xml, -1, &error))
+    if (!gtk_ui_manager_add_ui_from_string(UIManager, ui_xml, -1, &error))
     {
         g_error(_("Could not merge UI, error was: %s\n"), error->message);
         g_error_free(error);
     }
-
     gtk_ui_manager_insert_action_group(UIManager, ActionGroup, 0);
     gtk_window_add_accel_group(GTK_WINDOW(MainWindow), gtk_ui_manager_get_accel_group(UIManager));
-    /* Menu is placed in a handlebar */
-    menubar = gtk_handle_box_new();
-    gtk_container_add(GTK_CONTAINER(menubar), gtk_ui_manager_get_widget(UIManager, "/MenuBar"));
+
+    /* Menu (not placed in a handlebar) */
+    menubar = gtk_ui_manager_get_widget(UIManager, "/MenuBar");
     Init_Menu_Bar();
     gtk_widget_show_all(menubar);
 
@@ -308,7 +313,6 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
     toolbar = gtk_handle_box_new();
     toolbarwidget = gtk_ui_manager_get_widget(UIManager, "/ToolBar");
     gtk_container_add(GTK_CONTAINER(toolbar), toolbarwidget);
-    //gtk_container_set_border_width(GTK_CONTAINER(toolbarwidget),2);
     gtk_toolbar_set_style(GTK_TOOLBAR(toolbarwidget), GTK_TOOLBAR_ICONS);
     Set_Tips_Color(GTK_TOOLBAR(toolbarwidget)->tooltips);
     gtk_widget_show_all(toolbar);
@@ -331,6 +335,14 @@ void Init_Menu_Bar (void)
             G_CALLBACK(Check_Menu_Item_Toggled_Browse_Subdir),NULL);
     }
 
+    CheckMenuItemBrowseHiddenDirMainMenu = gtk_ui_manager_get_widget(UIManager, "/MenuBar/BrowserMenu/BrowseHiddenDir");
+    if (CheckMenuItemBrowseHiddenDirMainMenu)
+    {
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(CheckMenuItemBrowseHiddenDirMainMenu),BROWSE_HIDDEN_DIR);
+        g_signal_connect(G_OBJECT(CheckMenuItemBrowseHiddenDirMainMenu),"toggled",
+            G_CALLBACK(Check_Menu_Item_Toggled_Browse_Hidden_Dir),NULL);
+    }
+
     /* If entry not implemented */
     //{GtkWidget *widget = gtk_item_factory_get_widget_by_action(ItemFactory,FILENAME_FROM_TXT);
     //if (widget) gtk_widget_set_sensitive(widget,FALSE);}
@@ -349,6 +361,24 @@ void Check_Menu_Item_Update_Browse_Subdir (void)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(CheckMenuItemBrowseSubdirMainMenu),BROWSE_SUBDIR);
 }
 
+/*
+ * Callback to update state of check button to show hiddendirectories into menu
+ */
+void Check_Menu_Item_Toggled_Browse_Hidden_Dir (GtkWidget *checkmenuitem)
+{
+    BROWSE_HIDDEN_DIR = GTK_CHECK_MENU_ITEM(checkmenuitem)->active;
+    Check_Menu_Item_Update_Browse_Hidden_Dir();
+
+    // Reload directory, in case we have changed BROWSE_HIDDEN_DIR
+    Browser_Tree_Rebuild(NULL);
+}
+void Check_Menu_Item_Update_Browse_Hidden_Dir (void)
+{
+#ifndef WIN32
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(CheckMenuItemBrowseHiddenDirMainMenu),BROWSE_HIDDEN_DIR);
+#endif
+}
+
 
 
 
