@@ -32,6 +32,7 @@ GtkActionGroup *ActionGroup;
 guint           StatusBarContext;
 
 GtkWidget *CheckMenuItemBrowseSubdirMainMenu;
+GtkWidget *CheckMenuItemBrowseHiddenDirMainMenu;
 
 #define MENU_FILE       "FileMenu"
 #define MENU_BROWSER    "BrowserMenu"
@@ -69,7 +70,8 @@ GtkWidget *CheckMenuItemBrowseSubdirMainMenu;
 #define AM_LOAD_DEFAULT_DIR         "GoToDefaultPath"
 #define AM_SET_PATH_AS_DEFAULT      "SetDefaultPath"
 #define AM_RENAME_DIR               "RenameDir"
-#define AM_RECURSE                  "BrowseSubdir"
+#define AM_BROWSE_SUBDIR            "BrowseSubdir"
+#define AM_BROWSER_HIDDEN_DIR       "BrowseHiddenDir"
 #define AM_COLLAPSE_TREE            "CollapseTree"
 #define AM_INITIALIZE_TREE          "RefreshTree"
 #define AM_RELOAD_DIRECTORY         "ReloadDir"
@@ -77,7 +79,6 @@ GtkWidget *CheckMenuItemBrowseSubdirMainMenu;
 #define AM_BROWSE_DIRECTORY_WITH    "BrowseDir"
 #define AM_BROWSE_FILE_WITH         "Open"
 #define AM_OPEN_OPTIONS_WINDOW      "Preferences"
-#define AM_SAVE_CONFIG              "SaveConfig"
 #define AM_SCANNER_FILL_TAG         "FillTag"
 #define AM_SCANNER_RENAME_FILE      "RenameFile"
 #define AM_SCANNER_PROCESS_FIELDS   "ProcessFields"
@@ -142,12 +143,14 @@ struct _Action_Pair {
  * Prototypes *
  **************/
 
-void       Create_UI(GtkWidget **menubar, GtkWidget **toolbar);
-GtkWidget *Create_Status_Bar (void);
-void       Statusbar_Message (gchar *message, gint with_timer);
+void       Create_UI           (GtkWidget **menubar, GtkWidget **toolbar);
+GtkWidget *Create_Status_Bar   (void);
+void       Statusbar_Message   (gchar *message, gint with_timer);
 GtkWidget *Create_Progress_Bar (void);
 
 void Check_Menu_Item_Toggled_Browse_Subdir (GtkWidget *checkmenuitem);
-void Check_Menu_Item_Update_Browse_Subdir (void);
+void Check_Menu_Item_Update_Browse_Subdir  (void);
+void Check_Menu_Item_Toggled_Browse_Hidden_Dir (GtkWidget *checkmenuitem);
+void Check_Menu_Item_Update_Browse_Hidden_Dir  (void);
 
 #endif /* __BAR_H__ */
