@@ -66,6 +66,10 @@ GtkListStore *BrowserEntryModel;
 GtkWidget *BrowserHPaned;
 GtkWidget *ArtistAlbumVPaned;
 
+GtkWidget *RenameDirectoryWindow;
+GtkWidget *RenameDirectoryMaskCombo;
+GtkWidget *RenameDirectoryPreviewLabel;
+
 
 
 /**************
