@@ -80,10 +80,12 @@ const CharsetInfo charset_trans_array[] = {
     {N_("Turkish (Windows-1254)"),            "windows-1254"  },
     {N_("Unicode (UTF-7)"),                   "UTF-7"         },
     {N_("Unicode (UTF-8)"),                   "UTF-8"         },
+    
     {N_("Unicode (UTF-16BE)"),                "UTF-16BE"      },
     {N_("Unicode (UTF-16LE)"),                "UTF-16LE"      },
-    {N_("Unicode (UTF-32BE)"),                "UTF-32BE"      },
-    {N_("Unicode (UTF-32LE)"),                "UTF-32LE"      },
+    //{N_("Unicode (UTF-32BE)"),                "UTF-32BE"      },
+    //{N_("Unicode (UTF-32LE)"),                "UTF-32LE"      },
+    
     {N_("Vietnamese (VISCII)"),               "VISCII"        },
     {N_("Vietnamese (Windows-1258)"),         "windows-1258"  },
     {N_("Visual Hebrew (ISO-8859-8)"),        "ISO-8859-8"    },
@@ -170,10 +172,10 @@ insert_locales (GHashTable *encodings, char *enc, ...)
 }
 
 /* stolen from gnome-desktop-item.c */
+/* make a standard conversion table from the desktop standard spec */
 void
 Charset_Insert_Locales_Init (void)
 {
-/* make a standard conversion table from the desktop standard spec */
     encodings = g_hash_table_new (g_str_hash, g_str_equal);
 
     /* "C" is plain ascii */
@@ -188,7 +190,7 @@ Charset_Insert_Locales_Init (void)
         insert_locales (encodings, "GB2312", "zh_CN", NULL);
     }
     insert_locales (encodings, "EUC-JP", "ja", NULL);
-    insert_locales (encodings, "UHC", "ko", NULL);
+    insert_locales (encodings, "EUC-KR", "ko", NULL);
     /*insert_locales (encodings, "GEORGIAN-ACADEMY", NULL);*/
     insert_locales (encodings, "GEORGIAN-PS", "ka", NULL);
     insert_locales (encodings, "ISO-8859-1", "br", "ca", "da", "de", "en", "es", "eu", "fi", "fr", "gl", "it", "nl", "wa", "no", "pt", "pt", "sv", NULL);
@@ -218,7 +220,7 @@ Charset_Insert_Locales_Destroy (void)
 }
 
 /* stolen from gnome-desktop-item.c */
-static const char *
+const char *
 get_encoding_from_locale (const char *locale)
 {
     char lang[3];
@@ -227,6 +229,11 @@ get_encoding_from_locale (const char *locale)
     if (locale == NULL)
         return NULL;
 
+    /* if locale includes encoding, use it *//*
+    encoding = strchr (locale, '.');
+    if (encoding != NULL) {
+        return encoding+1;
+    }*/
     /* if locale includes encoding (that isn't UTF-8), use it */
     encoding = strchr (locale, '.');
     if (encoding != NULL && strncmp (encoding, ".UTF-8", 6)) {
@@ -244,55 +251,82 @@ get_encoding_from_locale (const char *locale)
     return g_hash_table_lookup (encodings, lang);
 }
 
+
 /*
-char *
-rb_unicodify (const char *str)
+ * Return the locale from LANG if exists, else from LC_ALL
+ *
+ * http://www.opengroup.org/onlinepubs/009695399/basedefs/xbd_chap08.html#tag_08_02
+ */
+const gchar *get_locale (void)
 {
-    char *ret = NULL;
-    const char *char_encoding;
-
-    // Try validating it as UTF-8 first
-    if (g_utf8_validate (str, -1, NULL))
-        return g_strdup (str);
-
-    // Failing that, try the legacy encoding associated with the locale.
-    char_encoding = get_encoding_from_locale (getenv ("LANG"));
-    if (char_encoding == NULL)
-        ret = NULL;
+    if (g_getenv("LANG"))
+        return g_getenv("LANG");
+    
+    else if (g_getenv("LC_ALL"))
+        return g_getenv("LC_ALL");
+    
+    else if (g_getenv("LC_CTYPE"))
+        return g_getenv("LC_CTYPE");
+    
     else
-        ret = g_convert (str, -1, "UTF-8", char_encoding,
-                 NULL, NULL, NULL);
-    // Failing that, try ISO-8859-1
-    if (!ret)
-        ret = g_convert (str, -1, "UTF-8", "ISO-8859-1",
-                 NULL, NULL, NULL);
-
-    return ret;
-}*/
+        return NULL;
+}
 
 
 
 
-
-gchar *convert_string (const gchar *string, const gchar *from_codeset, const gchar *to_codeset)
+/*
+ * convert_string :
+ *  - display_error : if TRUE, may return an escaped string and display an error 
+ *                    message (if conversion fails).
+ */
+gchar *convert_string (const gchar *string, const gchar *from_codeset,
+                       const gchar *to_codeset, const gboolean display_error)
+{
+    return convert_string_1(string, -1, from_codeset, to_codeset, display_error);
+}
+/* Length must be passed, as the string might be Unicode, in which case we can't
+ * count zeroes (see strlen call below). */
+gchar *convert_string_1 (const gchar *string, gssize length, const gchar *from_codeset,
+                         const gchar *to_codeset, const gboolean display_error)
 {
     gchar *output;
     GError *error = NULL;
+    gsize bytes_written;
 
     if (!string)
         return NULL;
     
-    output = g_convert(string, -1, to_codeset, from_codeset, NULL, NULL, &error);
+    output = g_convert(string, length, to_codeset, from_codeset, NULL, &bytes_written, &error);
+    //output = g_convert_with_fallback(string, length, to_codeset, from_codeset, "?", NULL, &bytes_written, &error);
 
     if (output == NULL)
     {
         gchar *escaped_str = g_strescape(string, NULL);
-        g_warning("convert_string(): Failed conversion from charset '%s' to '%s'. "
-                  "String '%s'. Errcode %d (%s).\n",
-                  from_codeset, to_codeset, escaped_str, error->code, error->message);
+        if (display_error)
+        {
+            g_warning("convert_string(): Failed conversion from charset '%s' to '%s'. "
+                      "String '%s'. Errcode %d (%s).\n",
+                      from_codeset, to_codeset, escaped_str, error->code, error->message);
+        }
         g_free(escaped_str);
         g_error_free(error);
-        return g_strdup(string);
+        // Return the input string without converting it. If the string is 
+        // displayed in the UI, it must be in UTF-8!
+        if ( (g_ascii_strcasecmp(to_codeset, "UTF-8"))
+        ||   (g_utf8_validate(string, -1, NULL)) )
+        {
+            return g_strdup(string);
+        }
+    }else
+    {
+        // Patch from Alexey Illarionov:
+        //    g_convert returns null-terminated string only with one \0 at the
+        // end. It can cause some garbage at the end of a string for UTF-16. 
+        // The second \0 should be set manually. 
+        output = g_realloc(output, bytes_written + 2);
+        if (output != NULL)
+            output[bytes_written] = output[bytes_written + 1] = 0;
     }
 
     return output;
@@ -323,9 +357,9 @@ gchar *convert_to_utf8 (const gchar *string)
         g_free(escaped_str);
 
         if (g_utf8_validate(string, -1, NULL))
-            g_warning("convert_to_utf8(): String was valid UTF8.\n");
+            g_warning("convert_to_utf8(): String was valid UTF-8.\n");
         else
-            g_warning("convert_to_utf8(): String was INVALID UTF8.\n");
+            g_warning("convert_to_utf8(): String was INVALID UTF-8.\n");
 
         g_error_free(error);
         return g_strdup(string);
@@ -355,9 +389,9 @@ gchar *convert_from_utf8 (const char *string)
         g_free(escaped_str);
 
         if (g_utf8_validate(string, -1, NULL))
-            g_warning("convert_from_utf8(): String was valid UTF8.\n");
+            g_warning("convert_from_utf8(): String was valid UTF-8.\n");
         else
-            g_warning("convert_from_utf8(): String was INVALID UTF8.\n");
+            g_warning("convert_from_utf8(): String was INVALID UTF-8.\n");
 
         g_error_free(error);
         return g_strdup(string);
@@ -368,66 +402,6 @@ gchar *convert_from_utf8 (const char *string)
 
 
 
-/*
- * Conversion with ISO-8859-1 for ID3v2.3 tags (current_charset <===> ISO-8859-1)
- */
-/***
-char *convert_to_iso88591 (const char *string)
-{
-    const gchar *charset;
-    g_get_charset(&charset);
-
-    // No conversion needed
-    if (strcmp(charset, "ANSI_X3.4-1968") == 0)
-        return g_strdup(string);
-
-    return convert_string(string, charset, "ISO-8859-1");
-}
-
-char *convert_from_iso88591 (const char *string)
-{
-    const gchar *charset;
-    g_get_charset(&charset);
-
-    // No conversion needed
-    if (strcmp(charset, "ANSI_X3.4-1968") == 0)
-        return g_strdup(string);
-
-    return convert_string(string, "ISO-8859-1", charset);
-}
-***/
-
-
-
-/*
- * Conversion with "this_charset" for ID3v2.3 tags (current_charset <===> this_charset)
- */
-/***
-// Convert from the locale charset to 'this_charset'
-char *convert_to_this_charset (const char *string, char *this_charset)
-{
-    const gchar *charset;
-    g_get_charset(&charset);
-
-    return convert_string(string, charset, this_charset);
-}
-
-// Convert from 'this_charset' to the locale charset
-char *convert_from_this_charset (const char *string, char *this_charset)
-{
-    const gchar *charset;
-    g_get_charset(&charset);
-
-    return convert_string(string, this_charset, charset);
-}
-***/
-
-
-/*
- * Functions to translate filename to UTF-8
- * Based around the ideas under "File Name Encodings" at
- *    http://developer.gnome.org/doc/API/2.0/glib/glib-Character-Set-Conversion.html
- */
 /*
  * Convert a string from the filename system encoding to UTF-8.
  *  - conversion OK : returns the UTF-8 string (new allocated)
@@ -436,50 +410,46 @@ char *convert_from_this_charset (const char *string, char *this_charset)
 gchar *filename_to_display (const gchar *string)
 {
     GError *error = NULL;
-    gchar *temp;
     
     if (!string)
         return NULL;
 
-    temp = g_filename_to_utf8(string, -1, NULL, NULL, &error);
-    if (!temp)
+    if (g_utf8_validate(string, -1, NULL))
+    {
+        // String already in UTF-8
+        return g_strdup(string);
+    }else
     {
-        // Conversion KO!
         const gchar *char_encoding;
-        gchar *ret;
-        
-        // Try the legacy encoding associated with the locale.
-        char_encoding = get_encoding_from_locale(getenv("LANG"));
+        gchar *ret = NULL;
+
+        // Get encoding associated to the locale without using UTF-8 (ex , if LANG=fr_FR.UTF-8 it will return ISO-8859-1)
+        char_encoding = get_encoding_from_locale(get_locale());
         if (char_encoding)
         {
-            ret = g_convert(string, -1, "UTF-8", char_encoding, NULL, NULL, NULL);
-        }else
+            //g_print("> char_encoding: %s\n",char_encoding);
+            error = NULL;
+            ret = g_convert(string, -1, "UTF-8", char_encoding, NULL, NULL, &error);
+        }
+
+        if (!ret)
         {
             // Failing that, try ISO-8859-1
-            ret = g_convert(string, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
+            error = NULL;
+            ret = g_convert(string, -1, "UTF-8", "ISO-8859-1", NULL, NULL, &error);
         }
 
         if (!ret)
         {
             gchar *escaped_str = g_strescape(string, NULL);
-            g_warning(_("The filename '%s' couldn't be converted into UTF-8 (%s).\n"
-                        "To fix : this file name musn't be in UTF-8 encoding. So "
-                        "specify the right encoding for file name in the "
-                        "G_FILENAME_ENCODING environment variable (for example : "
-                        "export G_FILENAME_ENCODING=ISO-8859-1).\n"),
-                        escaped_str, error->message ? error->message : _("Invalid UTF-8"));
+            g_warning(_("The filename '%s' couldn't be converted into UTF-8 (%s).\n"),
+                        escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
             g_clear_error(&error);
-    
+
             return escaped_str;
-        }else
-        {
-            return ret;
         }
-        
-    }else
-    {
-        // Conversion OK
-        return temp;
+
+        return ret;
     }
 }
 
@@ -490,21 +460,90 @@ gchar *filename_to_display (const gchar *string)
  */
 gchar *filename_from_display (const gchar *string)
 {
-    gchar *temp;
+    GError *error = NULL;
+    gchar *ret = NULL;
+    const gchar *char_encoding = NULL;
+    //const gchar *filename_encoding = NULL;
 
     if (!string) return NULL;
     
-    temp = g_filename_from_utf8(string, -1, NULL, NULL, NULL);
-    if (!temp)
+    // Get system encoding from LANG if found (ex : fr_FR.UTF-8 => UTF-8)
+    if (get_locale())
+        char_encoding = strchr(get_locale(), '.');
+    
+    if (char_encoding)
+        char_encoding = char_encoding+1; // Skip the '.'
+    if (char_encoding)
+    {
+        error = NULL;
+        
+        if (FILENAME_CHARACTER_SET_OTHER)
+        {
+            ret = g_convert(string, -1, char_encoding, "UTF-8", NULL, NULL, &error);
+            
+        }else if (FILENAME_CHARACTER_SET_APPROXIMATE)
+        {
+            // iconv_open (3):
+            // When the string "//TRANSLIT" is appended to tocode, transliteration
+            // is activated. This means that when a character cannot be represented
+            // in the target character set, it can be approximated through one or
+            // several similarly looking characters.
+            gchar *enc = g_strconcat(char_encoding, "//TRANSLIT", NULL);
+            ret = g_convert(string, -1, enc, "UTF-8", NULL, NULL, &error);
+            g_free(enc);
+            
+        }else if (FILENAME_CHARACTER_SET_DISCARD)
+        {
+            // iconv_open (3):
+            // When the string "//IGNORE" is appended to tocode, characters that
+            // cannot be represented in the target character set will be silently
+            // discarded.
+            gchar *enc = g_strconcat(char_encoding, "//IGNORE", NULL);
+            ret = g_convert(string, -1, enc, "UTF-8", NULL, NULL, &error);
+            g_free(enc);
+        }
+    }
+    
+    if (!ret)
+    {
+        // Get system encoding from locale in LANG if found (ex : fr_FR.UTF-8 => fr_FR => ISO-8859-1)
+        char_encoding = get_encoding_from_locale(get_locale());
+        if (char_encoding)
+        {
+            //g_print("> char_encoding: %s\n",char_encoding);
+            error = NULL;
+            ret = g_convert(string, -1, char_encoding, "UTF-8", NULL, NULL, &error);
+        }
+    }
+        
+    if (!ret)
+    {
+        // Failing that, try ISO-8859-1
+        error = NULL;
+        ret = g_convert(string, -1, "ISO-8859-1", "UTF-8", NULL, NULL, &error);
+    }
+
+    if (!ret)
+    {
+        if (g_utf8_validate(string, -1, NULL))
+        {
+            // String already in UTF-8
+            ret = g_strdup(string);
+        }
+    }
+    
+    if (!ret)
     {
         // Conversion KO!
         gchar *escaped_str = g_strescape(string, NULL);
-        g_warning(_("The UTF-8 string '%s' couldn't be converted into filename "
-                    "encoding\n"), escaped_str);
-        g_free(escaped_str);
+        g_warning(_("The UTF-8 string '%s' couldn't be converted into filename encoding (%s)\n."),
+                    escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
+        g_clear_error(&error);
+
+        return escaped_str;
     }
 
-    return temp; // We need to catch errors (e.g. temp=NULL) in the real code
+    return ret; // We need to catch errors (e.g. temp=NULL) in the real code
 }
 
 
@@ -555,22 +594,31 @@ gchar *Charset_Get_Title_From_Name (gchar *charset_name)
 
 /*
  * Test if the conversion is supported between two character sets ('from' and 'to)
+ * (function called in the preferences window).
+ * Note : for UTF-16 (2 byte for each character) we make a special test...
  */
-
 gboolean test_conversion_charset (const gchar *from, const gchar *to)
 {
     gchar *temp;
-    GError *error = NULL;
-
+    
     if (!from || !to)
         return FALSE;
     
     // Do a quick test conversion and examine error output
-    temp = g_convert("a", -1, to, from, NULL, NULL, &error);
-
+    if ( strcmp(from,"UTF-16BE") == 0 )
+    {
+        temp = convert_string_1("F\0O\0O\0\0\0", 6, from, to, FALSE);
+    }else if ( strcmp(from,"UTF-16LE") == 0 )
+    {
+        temp = convert_string_1("\0F\0O\0O\0\0", 6, from, to, FALSE);
+    }else
+    {
+        temp = convert_string("FOO", from, to, FALSE);
+    }
+    
     if (!temp)
     {
-        // Error in conversion
+        /*// Error in conversion
         if (error && error->code == G_CONVERT_ERROR_NO_CONVERSION)
         {
             g_print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_NO_CONVERSION)\n",from,to);
@@ -595,13 +643,13 @@ gboolean test_conversion_charset (const gchar *from, const gchar *to)
         }
         
         if (error)
-            g_error_free(error);
+            g_error_free(error);*/
         return FALSE;
     } else
     {
-        // No error
+        /*// No error
         if (error)
-            g_error_free(error);
+            g_error_free(error);*/
         g_free(temp);
         return TRUE;
     }
