@@ -113,11 +113,11 @@ typedef enum
 {                    //                                             (.ext) is not so popular 
     MP2_FILE = 0,    // Mpeg audio Layer 2        : .mp2            (.mpg) (.mpga)
     MP3_FILE,        // Mpeg audio Layer 3        : .mp3            (.mpg) (.mpga)
+    MP4_FILE,        // Mpeg audio Layer 4 / AAC  : .mp4            (.m4a) (.m4p)
     OGG_FILE,        // Ogg Vorbis audio          : .ogg            (.ogm)
     FLAC_FILE,       // FLAC (lossless)           : .flac .fla
     MPC_FILE,        // MusePack                  : .mpc .mp+ .mpp
     MAC_FILE,        // Monkey's Audio (lossless) : .ape            (.mac)
-//    AAC_FILE,        // AAC audio files           : .m4a .m4p
 //    SPEEX_FILE,      // Speech audio files        : .spx
     OFR_FILE,        // OptimFROG (lossless)      : .ofr .ofs
     UNKNOWN_FILE
@@ -133,6 +133,7 @@ typedef enum
     OGG_TAG,
     APE_TAG,
     FLAC_TAG,
+    MP4_TAG,
     UNKNOWN_TAG
 } ET_Tag_Type;
 
@@ -245,11 +246,14 @@ static const ET_File_Description ETFileDescription[] =
     {MPC_FILE,     ".mpp",  APE_TAG},  // Implemented by Artur Polaczynski
     {MAC_FILE,     ".ape",  APE_TAG},  // Implemented by Artur Polaczynski
     {MAC_FILE,     ".mac",  APE_TAG},  // Implemented by Artur Polaczynski
-//    {AAC_FILE,     ".m4a",  ID3_TAG},
-//    {AAC_FILE,     ".m4p",  ID3_TAG},
-//    {SPEEX_FILE,   ".spx",  OGG_TAG},
     {OFR_FILE,     ".ofr",  APE_TAG},
     {OFR_FILE,     ".ofs",  APE_TAG},
+#ifdef ENABLE_MP4
+    {MP4_FILE,     ".mp4",  MP4_TAG},  // Implemented by Michael Ihde
+    {MP4_FILE,     ".m4a",  MP4_TAG},  // Implemented by Michael Ihde
+    {MP4_FILE,     ".m4p",  MP4_TAG},  // Implemented by Michael Ihde
+#endif
+//    {SPEEX_FILE,   ".spx",  OGG_TAG},
     {UNKNOWN_FILE, "",      UNKNOWN_TAG}    /* This item must be placed to the end! */
 };
 
@@ -395,8 +399,9 @@ gchar   *ET_File_Name_Generate                   (ET_File *ETFile, gchar *new_fi
 guint    ET_Get_Number_Of_Files_In_Directory     (gchar *path_utf8);
 gchar   *ET_Utf8_Validate_Full_String            (gchar *string_to_validate);
 
-void ET_Sort_Displayed_File_List                          (ET_Sorting_Type Sorting_Type);
-void ET_Sort_Displayed_File_List_And_Update_UI            (ET_Sorting_Type Sorting_Type);
+GList *ET_Sort_File_List                                  (GList *ETFileList, ET_Sorting_Type Sorting_Type);
+void   ET_Sort_Displayed_File_List                        (ET_Sorting_Type Sorting_Type);
+void   ET_Sort_Displayed_File_List_And_Update_UI          (ET_Sorting_Type Sorting_Type);
 gint ET_Comp_Func_Sort_File_By_Ascending_Filename         (ET_File *ETFile1, ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Descending_Filename        (ET_File *ETFile1, ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Ascending_Creation_Date    (ET_File *ETFile1, ET_File *ETFile2);
