@@ -112,7 +112,8 @@ gboolean Flac_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
 
     /* Decoding FLAC file */
     tmp_decoder = FLAC__file_decoder_new();
-    if (tmp_decoder == 0) {
+    if (tmp_decoder == 0)
+    {
         return FALSE;
     }
 
@@ -123,17 +124,19 @@ gboolean Flac_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
     FLAC__file_decoder_set_metadata_callback(tmp_decoder, metadata_callback_);
     FLAC__file_decoder_set_error_callback   (tmp_decoder, error_callback_);
     FLAC__file_decoder_set_client_data      (tmp_decoder, &tmp_file_info);
-    if (FLAC__file_decoder_init(tmp_decoder) != FLAC__FILE_DECODER_OK) {
+    if (FLAC__file_decoder_init(tmp_decoder) != FLAC__FILE_DECODER_OK)
+    {
         return FALSE;
     }
 
     // In FLAC 1.0.3, is used : FLAC__file_decoder_process_metadata
     // In FLAC 1.0.4, is used : FLAC__file_decoder_process_until_end_of_metadata
 #if ( (LIBFLAC_MAJOR <= 1) && (LIBFLAC_MINOR <= 0) && (LIBFLAC_PATCH <= 3) )
-    if (!FLAC__file_decoder_process_metadata(tmp_decoder)) { // FLAC 1.0.3
+    if (!FLAC__file_decoder_process_metadata(tmp_decoder)) // FLAC 1.0.3
 #else
-    if (!FLAC__file_decoder_process_until_end_of_metadata(tmp_decoder)) { // FLAC 1.0.4 (Bastian Kleineidam)
+    if (!FLAC__file_decoder_process_until_end_of_metadata(tmp_decoder)) // FLAC 1.0.4 (Bastian Kleineidam)
 #endif
+    {
         return FALSE;
     }
 
