@@ -113,7 +113,12 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         gchar *filename_utf8 = filename_to_display(filename);
         if ( iter == NULL )
         {
+#ifdef WIN32
+            const char ** const iter = FLAC__Metadata_SimpleIteratorStatusString; /* this is for win32 auto-import of this external symbol works */
+            flac_error_msg = iter[FLAC__METADATA_SIMPLE_ITERATOR_STATUS_MEMORY_ALLOCATION_ERROR];
+#else
             flac_error_msg = FLAC__Metadata_SimpleIteratorStatusString[FLAC__METADATA_SIMPLE_ITERATOR_STATUS_MEMORY_ALLOCATION_ERROR];
+#endif
         }else
         {
             flac_error_msg = FLAC__Metadata_SimpleIteratorStatusString[FLAC__metadata_simple_iterator_status(iter)];
@@ -174,9 +179,9 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->title = g_strdup(field_value);
                 else
                     FileTag->title = g_strconcat(FileTag->title,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
         }
-        g_free(field_value);
     }
 
     /**********
@@ -202,8 +207,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->artist = g_strdup(field_value);
                 else
                     FileTag->artist = g_strconcat(FileTag->artist,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
         }
     }
 
@@ -230,8 +235,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->album = g_strdup(field_value);
                 else
                     FileTag->album = g_strconcat(FileTag->album,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
         }
     }
 
@@ -306,8 +311,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 {
                     FileTag->track_total = g_strdup(field_value);
                 }
+                g_free(field_value);
             }
-            g_free(field_value);
         }
         // Below is also filled track_total if not done here
     }
@@ -346,8 +351,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     }
                     FileTag->track = g_strdup(field_value);
                 }
+                g_free(field_value);
             }
-            g_free(field_value);
         }
     }
 
@@ -374,9 +379,9 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->genre = g_strdup(field_value);
                 else
                     FileTag->genre = g_strconcat(FileTag->genre,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
-        }                
+        }
     }
 
     /***********
@@ -402,8 +407,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->comment = g_strdup(field_value);
                 else
                     FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
         }                
     }
 
@@ -430,8 +435,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->composer = g_strdup(field_value);
                 else
                     FileTag->composer = g_strconcat(FileTag->composer,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
         }
     }
 
@@ -458,8 +463,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->orig_artist = g_strdup(field_value);
                 else
                     FileTag->orig_artist = g_strconcat(FileTag->orig_artist,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
         }
     }
 
@@ -486,8 +491,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->copyright = g_strdup(field_value);
                 else
                     FileTag->copyright = g_strconcat(FileTag->copyright,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
         }
     }
 
@@ -514,8 +519,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->url = g_strdup(field_value);
                 else
                     FileTag->url = g_strconcat(FileTag->url,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
         }
     }
 
@@ -542,8 +547,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->encoded_by = g_strdup(field_value);
                 else
                     FileTag->encoded_by = g_strconcat(FileTag->encoded_by,MULTIFIELD_SEPARATOR,field_value,NULL);
+                g_free(field_value);
             }
-            g_free(field_value);
         }
     }
 
@@ -554,20 +559,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     for (i=0;i<(guint)vc->num_comments;i++)
     {
         field = &vc->comments[i];
-        if ( strncasecmp(field->entry,"TITLE=",       MIN(6,  field->length)) != 0
-          && strncasecmp(field->entry,"ARTIST=",      MIN(7,  field->length)) != 0
-          && strncasecmp(field->entry,"ALBUM=",       MIN(6,  field->length)) != 0
-          && strncasecmp(field->entry,"DISCNUMBER=",  MIN(11, field->length)) != 0
-          && strncasecmp(field->entry,"DATE=",        MIN(5,  field->length)) != 0
-          && strncasecmp(field->entry,"TRACKNUMBER=", MIN(12, field->length)) != 0
-          && strncasecmp(field->entry,"TRACKTOTAL=",  MIN(11, field->length)) != 0
-          && strncasecmp(field->entry,"GENRE=",       MIN(6,  field->length)) != 0
-          && strncasecmp(field->entry,"DESCRIPTION=", MIN(12, field->length)) != 0
-          && strncasecmp(field->entry,"COMPOSER=",    MIN(6,  field->length)) != 0
-          && strncasecmp(field->entry,"PERFORMER=",   MIN(6,  field->length)) != 0
-          && strncasecmp(field->entry,"COPYRIGHT=",   MIN(6,  field->length)) != 0
-          && strncasecmp(field->entry,"LICENSE=",     MIN(6,  field->length)) != 0
-          && strncasecmp(field->entry,"ENCODED-BY=",  MIN(6,  field->length)) != 0 )
+        if ( strncasecmp((gchar *)field->entry,"TITLE=",       MIN(6,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"ARTIST=",      MIN(7,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"ALBUM=",       MIN(6,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"DISCNUMBER=",  MIN(11, field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"DATE=",        MIN(5,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"TRACKNUMBER=", MIN(12, field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"TRACKTOTAL=",  MIN(11, field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"GENRE=",       MIN(6,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"DESCRIPTION=", MIN(12, field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"COMPOSER=",    MIN(6,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"PERFORMER=",   MIN(6,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"COPYRIGHT=",   MIN(6,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"LICENSE=",     MIN(6,  field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"ENCODED-BY=",  MIN(6,  field->length)) != 0 )
         {
             //g_print("custom %*s\n", field->length, field->entry);
             FileTag->other = g_list_append(FileTag->other,g_strndup(field->entry, field->length));
@@ -577,7 +582,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     FLAC__metadata_object_delete(vc_block);
     FLAC__metadata_simple_iterator_delete(iter);
 
-    /* If no FLAC vorbis tag found : we try to get the ID3 tag if it exists (will be deleted when writing the tag */
+    /* If no FLAC vorbis tag found : we try to get the ID3 tag if it exists
+     * (will be deleted when writing the tag */
     if ( FileTag->title       == NULL
       && FileTag->artist      == NULL
       && FileTag->album       == NULL
@@ -595,7 +601,8 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     {
         gint rc = Id3tag_Read_File_Tag(filename,FileTag);
 
-        // If an ID3 tag has been found, we mark the file as unsaved to rewritte a flac tag
+        // If an ID3 tag has been found (and no FLAC tag), we mark the file as
+        // unsaved to rewrite a flac tag
         if ( FileTag->title       != NULL
           || FileTag->artist      != NULL
           || FileTag->album       != NULL
@@ -617,6 +624,26 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         return rc;
     }
 
+    /* Part to get cover artist :
+     * If we have read the ID3 tag previously we don't arrive here (and we have
+     * the picture if it exists)
+     * Else the ID3 tag wasn't read (as there was data in FLAC tag) so we try
+     * to read it only to get the picture (not supported by the FLAC tag) */
+    if (WRITE_ID3_TAGS_IN_FLAC_FILE && FileTag->picture == NULL)
+    {
+        File_Tag *FileTag_tmp = ET_File_Tag_Item_New();
+        gint rc = Id3tag_Read_File_Tag(filename,FileTag_tmp);
+        if (rc && FileTag_tmp->picture)
+        {
+            // Copy picture to FileTag
+            FileTag->picture = Picture_Copy(FileTag_tmp->picture);
+        }
+
+        ET_Free_File_Tag_Item(FileTag_tmp);
+
+        return rc;
+    }
+
     return TRUE;
 }
 
@@ -654,7 +681,12 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     {
         if ( iter == NULL )
         {
+#ifdef WIN32
+            const char **iter = FLAC__Metadata_SimpleIteratorStatusString;  /* this is for win32 auto-import of this external symbol works */
+            flac_error_msg = iter[FLAC__METADATA_SIMPLE_ITERATOR_STATUS_MEMORY_ALLOCATION_ERROR];
+#else
             flac_error_msg = FLAC__Metadata_SimpleIteratorStatusString[FLAC__METADATA_SIMPLE_ITERATOR_STATUS_MEMORY_ALLOCATION_ERROR];
+#endif
         }else
         {
             flac_error_msg = FLAC__Metadata_SimpleIteratorStatusString[FLAC__metadata_simple_iterator_status(iter)];
@@ -699,7 +731,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->title )
     {
         string  = g_strconcat("TITLE=",FileTag->title,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string); // Warning : g_utf8_strlen doesn't count the multibyte characters. Here we need the allocated size.
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -711,7 +743,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->artist )
     {
         string  = g_strconcat("ARTIST=",FileTag->artist,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -723,7 +755,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->album )
     {
         string  = g_strconcat("ALBUM=",FileTag->album,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -735,7 +767,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->disc_number )
     {
         string  = g_strconcat("DISCNUMBER=",FileTag->disc_number,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -747,7 +779,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->year )
     {
         string  = g_strconcat("DATE=",FileTag->year,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -759,7 +791,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->track )
     {
         string = g_strconcat("TRACKNUMBER=",FileTag->track,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -767,7 +799,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->track_total /*&& strlen(FileTag->track_total)>0*/ )
     {
         string = g_strconcat("TRACKTOTAL=",FileTag->track_total,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -779,7 +811,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->genre )
     {
         string  = g_strconcat("GENRE=",FileTag->genre,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -792,7 +824,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->comment )
     {
         string = g_strconcat("DESCRIPTION=",FileTag->comment,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -804,7 +836,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->composer )
     {
         string  = g_strconcat("COMPOSER=",FileTag->composer,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -816,7 +848,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->orig_artist )
     {
         string  = g_strconcat("PERFORMER=",FileTag->orig_artist,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -828,7 +860,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->copyright )
     {
         string  = g_strconcat("COPYRIGHT=",FileTag->copyright,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -840,7 +872,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->url )
     {
         string  = g_strconcat("LICENSE=",FileTag->url,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -852,7 +884,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->encoded_by )
     {
         string  = g_strconcat("ENCODED-BY=",FileTag->encoded_by,NULL);
-        field.entry = string;
+        field.entry = (FLAC__byte *)string;
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
@@ -868,7 +900,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
         if (list->data)
         {
             string = (gchar*)list->data;
-            field.entry = string;
+            field.entry = (FLAC__byte *)string;
             field.length = strlen(string);
             FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         }            
@@ -923,7 +955,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
         Id3tag_Write_File_Tag(ETFile);
     }else
     {
-        // Delete the ID3 tags (create a dummy ETFile)
+        // Delete the ID3 tags (create a dummy ETFile for the Id3tag_... function)
         ET_File   *ETFile_tmp    = ET_File_Item_New();
         File_Name *FileName_tmp  = ET_File_Name_Item_New();
         File_Tag  *FileTag_tmp   = ET_File_Tag_Item_New();
@@ -953,7 +985,7 @@ gchar *Flac_Tag_Validate_Utf8_Field (gchar *string)
     if ( !g_utf8_validate(string, -1, NULL) )
     {
         // Returns a native ISO-8859-15 string to UTF-8
-        return convert_string(string, "ISO-8859-1", "UTF-8");
+        return convert_string(string, "ISO-8859-1", "UTF-8",TRUE);
     }else
     {
         // Returns a native UTF-8 string
