@@ -30,7 +30,7 @@
 
 GtkWidget *WritePlaylistWindow;
 GtkWidget *playlist_use_mask_name;
-GtkWidget *PlayListNameCombo;
+GtkWidget *PlayListNameMaskCombo;
 GtkWidget *playlist_use_dir_name;
 GtkWidget *playlist_only_selected_files;
 GtkWidget *playlist_full_path;
@@ -41,7 +41,7 @@ GtkWidget *playlist_content_none;
 GtkWidget *playlist_content_filename;
 GtkWidget *playlist_content_mask;
 GtkWidget *PlayListContentMaskCombo;
-GtkListStore *PlayListNameModel;
+GtkListStore *PlayListNameMaskModel;
 GtkListStore *PlayListContentMaskModel;
 
 GtkWidget *LoadFilenameWindow;
@@ -79,6 +79,7 @@ void Load_Genres_List_To_UI (void);
 void Load_Track_List_To_UI  (void);
 void Init_Character_Translation_Table (void);
 void Init_Custom_Icons (void);
+gboolean Check_If_Executable_Exists (const gchar *program);
 
 // Mouse cursor
 void Init_Mouse_Cursor    (void);
@@ -107,10 +108,16 @@ void Strip_String (gchar *string);
 gint Combo_Alphabetic_Sort (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data);
 
 // Playlist window
-void Open_Write_Playlist_Window (void);
+void Open_Write_Playlist_Window          (void);
+void Write_Playlist_Window_Apply_Changes (void);
+
 // Search file window
 void Open_Search_File_Window (void);
+void Search_File_Window_Apply_Changes (void);
+
 // Load filenames window
-void Open_Load_Filename_Window (void);
+void Open_Load_Filename_Window          (void);
+void Load_Filename_Window_Apply_Changes (void);
+
 
 #endif /* __MISC_H__ */
