@@ -40,6 +40,11 @@
 #include "setting.h"
 #include "charset.h"
 
+#ifdef WIN32
+// for mkstemp
+#   include "win32dep.h"
+#endif
+
 
 /***************
  * Declaration *
@@ -47,7 +52,8 @@
 
 #define MULTIFIELD_SEPARATOR " - "
 
-/* Ogg Vorbis fields names in UTF-8 :
+/* Ogg Vorbis fields names in UTF-8 : http://www.xiph.org/vorbis/doc/v-comment.html
+ *
  * ALBUM       : if appropriate, an album name
  * ARTIST      : for information to be displayed on systems with limited display capabilities. it is not a replacement for the ENSEMBLE and PERFORMER tags, but typically will summarize them.
  * PUBLISHER   : who publishes the disc the track came from
@@ -157,6 +163,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         fseek(file, 0L, SEEK_SET);
     }
     }
+    
     state = vcedit_new_state();    // Allocate memory for 'state'
     if ( vcedit_open(state,file) < 0 )
     {
@@ -167,6 +174,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         return FALSE;
     }
 
+
     /* Get data from tag */
     vc = vcedit_comments(state);
     //{gint i; for (i=0;i<vc->comments;i++) g_print("%s -> Ogg vc:'%s'\n",g_path_get_basename(filename),vc->user_comments[i]);}
@@ -461,7 +469,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
             if (fread(tmp_id3, 1, 4, file_in) == 4)
             {
                 id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
-                                   | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
+                                | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
                 fseek(file_in, id3v2size, SEEK_SET);
             }else
             {
@@ -686,7 +694,6 @@ gboolean Ogg_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *st
     FILE  *file_out;
     gboolean return_code = TRUE;
 
-
     filename_tmp = g_strdup_printf("%s.XXXXXX",filename_in);
 
     if ((file_mkstemp = mkstemp(filename_tmp)) < 0)
@@ -701,6 +708,7 @@ gboolean Ogg_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *st
         close(file_mkstemp);
         remove(filename_tmp);
         g_free(filename_tmp);
+
         fclose(file_in);
         return FALSE;
     }
